@@ -1,14 +1,10 @@
 from pathlib import Path
 
-import plac
-
 from fastapi_generator.config import fs, ps
 from fastapi_generator.sub import SubApp
 
 
-@plac.pos('app_name', "sub app name", type=str)
-@plac.pos('api_name', "api name", type=str)
-def create_api(sub_app_name, api_name):
+def create_api(sub_app_name: str, api_name: str):
     sub_app_dir = Path(fs.sub_app_dir, sub_app_name)
     if not sub_app_dir.exists():
         sub_app = SubApp()
@@ -17,7 +13,3 @@ def create_api(sub_app_name, api_name):
     text = Path(ps.template_dir, 'api', 'api').read_text(encoding='utf8')
     with file.open(mode='w', encoding='utf8') as w:
         w.write(text)
-
-
-if __name__ == '__main__':
-    plac.call(create_api)
