@@ -5,7 +5,7 @@ from typing import Optional
 import sqlalchemy
 
 from fastapi_generator.config import fs, ps
-from fastapi_generator.utils.helper import OrmCreation, InterfaceCreation
+from fastapi_generator.utils.helper import OrmCreation, InterfaceCreation, TortoiseOrmCreation
 
 
 @dataclass
@@ -15,11 +15,11 @@ class MainApp:
 
     def create_app_with_orm(
             self, db_name: str = '', db_host: str = '', db_user: str = '', db_pswd: str = '',
-            is_only_orm: bool = False
+            is_only_orm: bool = False, mode: str = 'o'
     ):
         if not is_only_orm:
             self.write_files()
-        self.generate_orm(db_name=db_name, db_host=db_host, db_user=db_user, db_pswd=db_pswd)
+        self.generate_orm(db_name=db_name, db_host=db_host, db_user=db_user, db_pswd=db_pswd, mode=mode)
 
     def write_files(self):
 
@@ -65,13 +65,19 @@ class MainApp:
                 w.write(f"{package}\n")
 
     @staticmethod
-    def generate_orm(db_name: str, db_host: str, db_user: str, db_pswd: str):
+    def generate_orm(db_name: str, db_host: str, db_user: str, db_pswd: str, mode: str):
         if not fs.root_dir.exists():
             fs.root_dir.mkdir()
         database_url = f"mysql://{db_user}:{db_pswd}@{db_host}/" \
                        f"{db_name}?charset=utf8"
         engine = sqlalchemy.create_engine(database_url, encoding='utf-8')
-        orm_creation = OrmCreation(db_name=db_name, engine=engine, file=fs.orm_file)
+        if mode == 'o':
+            orm_class = OrmCreation
+        elif mode == 't':
+            orm_class = TortoiseOrmCreation
+        else:
+            raise ValueError('no orm')
+        orm_creation = orm_class(db_name=db_name, engine=engine, file=fs.orm_file)
         orm_creation.generate()
         interface_creation = InterfaceCreation(
             db_name=db_name, engine=engine, file=fs.interface_file)
